@@ -17,7 +17,8 @@ class LoggingUtils:  # pylint: disable=too-few-public-methods,no-member
     Class that provides useful functions for logging
     """
 
-    exception_formatter = ExceptionFormatter()
+    # Better exception: if max_length == None => no max len
+    exception_formatter = ExceptionFormatter(max_length=None) # type: ignore
 
     @staticmethod
     def get_logger(name: str, level: str = "INFO") -> loguru.Logger:
